@@ -1,9 +1,9 @@
 # Timor Leiderman AUG 2021
 
 from tensorflow.keras import layers
-from src.tensorflow_wavelets.utils import filters
-from src.tensorflow_wavelets.utils.helpers import *
-from src.tensorflow_wavelets.utils.cast import *
+from tensorflow_wavelets.utils import filters
+from tensorflow_wavelets.utils.helpers import *
+from tensorflow_wavelets.utils.cast import *
 
 # os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'  # for tensor flow warning
 # os.environ['CUDA_VISIBLE_DEVICES'] = '-1'
